==> websdk-bootstrap-2.4.0.tgz: package/README.md <==

# websdk-bootstrap

## Introduction
Nuance WebSDK Bootstrap project, provides an all in one javascript interface package for clients to use.

Built to leverage new technologies and provide more flexibility. The code provides API's for controlling the messaging experience on client web pages and, allows for simple configuration of the different chat rendering's.

## Usage (to build and host websdk-bootstrap localy)

### Run at the command line (on 1st install)
```
npm install
```

## Run to rebuild + serve locally
```
#Build only
npm run build

#Build and serve files
npm run start 
```
Will by default load to test.com with subdomain support, please add it to your hosts.
```
127.0.0.1 test.com
127.0.0.1 anySubDomainYouWant.test.com
```

### https option available parameters
`npm run start [subdomain name] [domain name] [port]`

To regenerate new pems for different domains use mkcert
https://github.com/FiloSottile/mkcert

*Note: Https will only be enabled if port 443 is set*

#### Start cmd examples ####

```
# Https with no subdomain
npm run start "" test.com 443

# Https with subdomain
npm run start "anySubDomainYouWant" test.com 443

# Http only
npm run start "xyz" test.com 8080
```


## Release Notes:
2.0.1 : Fix to retain scroll position when user does a touchMove on Chat Input

## Release Notes:
2.0.2 : Fix to resize the keyboard after use minimize and restore

## Release Notes:
2.0.3 : Wells Fargo - WebSDK - Minimize is not working correctly (SDK-1587)

## Release Notes:
2.1.0 : Calculating and setting the width, height to sandboxed iframe even when minimized so that when chat UI is created it has all information to render the bubbles 

## Release Notes:
2.2.0 : Multi c2c Button plugin added

## Release Notes:
2.3.0 : Exception handling in PostMessage handler to invalidate unintented post messages

## Release Notes:
2.4.0 : Update to sandbox Attributes

==> websdk-bootstrap-2.5.0.tgz: package/README.md <==

# websdk-bootstrap

## Introduction
Nuance WebSDK Bootstrap project, provides an all in one javascript interface package for clients to use.

Built to leverage new technologies and provide more flexibility. The code provides API's for controlling the messaging experience on client web pages and, allows for simple configuration of the different chat rendering's.

## Usage (to build and host websdk-bootstrap localy)

### Run at the command line (on 1st install)
```
npm install
```

## Run to rebuild + serve locally
```
#Build only
npm run build

#Build and serve files on https:/www.test.com
npm run start 
```
Will by default load to https:/www.test.com with subdomain support, please add it to your hosts.
```
127.0.0.1 www.test.com

Note: Any subdomain can be added and will be valid https
127.0.0.1 a.test.com b.test.com tc.test.com anySubDomainYouWant.test.com
```

### https option available parameters
`npm run start [subdomain name] [domain name] [port]`

To regenerate new pems for different domains use mkcert
https://github.com/FiloSottile/mkcert

#### Start cmd examples ####

```
# Https with custom subdomain
npm run start "anySubDomainYouWant" "test.com" 443

# Http only
npm run start "anySubDomainYouWant" "test.com" 80

```


## Release Notes:
2.0.1 : Fix to retain scroll position when user does a touchMove on Chat Input

## Release Notes:
2.0.2 : Fix to resize the keyboard after use minimize and restore

## Release Notes:
2.0.3 : Wells Fargo - WebSDK - Minimize is not working correctly (SDK-1587)

## Release Notes:
2.1.0 : Calculating and setting the width, height to sandboxed iframe even when minimized so that when chat UI is created it has all information to render the bubbles 

## Release Notes:
2.2.0 : Multi c2c Button plugin added

## Release Notes:
2.3.0 : Exception handling in PostMessage handler to invalidate unintented post messages

## Release Notes:
2.4.0 : Update to sandbox Attributes

## Release Notes:
2.5.0 : Added Capability to support first party cookie solution in bootstrap
        Support embedded to floating chat UI transition
